# State types
from __future__ import absolute_import
from __future__ import unicode_literals
JOB_STATE = 'job_state'
JOB_RUN_STATE = 'job_run_state'
MCP_STATE = 'mcp_state'
MESOS_STATE = 'mesos_state'
